@@ -12,6 +12,7 @@ from skimage.morphology import binary_opening
 from skimage.measure import label
 from skimage.morphology import local_maxima
 from skimage.restoration import rolling_ball
+from napari_tools_menu import register_function
 
 @napari_hook_implementation
 def napari_experimental_provide_function():
@@ -44,6 +45,7 @@ def _sobel_3d(image):
     ])
     return ndi.convolve(image, kernel)
 
+@register_function(menu="Segmentation > Split touching objects")
 def split_touching_objects(binary:LabelsData, sigma:float=3.5) -> LabelsData:
     """
     Takes a binary image and draws cuts in the objects similar to the ImageJ watershed algorithm.
@@ -57,7 +59,7 @@ def split_touching_objects(binary:LabelsData, sigma:float=3.5) -> LabelsData:
     # typical way of using scikit-image watershed
     distance = ndi.distance_transform_edt(binary)
     blurred_distance = gaussian(distance, sigma=sigma)
-    fp = np.ones((3, 3)) if len(binary.shape) == 2 else np.ones((3, 3, 3))
+    fp = np.ones((3,) * binary.ndim)
     coords = peak_local_max(blurred_distance, footprint=fp, labels=binary)
     mask = np.zeros(distance.shape, dtype=bool)
     mask[tuple(coords.T)] = True
@@ -75,7 +77,7 @@ def split_touching_objects(binary:LabelsData, sigma:float=3.5) -> LabelsData:
     almost = np.logical_not(np.logical_xor(edges != 0, edges2 != 0)) * binary
     return binary_opening(almost)
 
-
+@register_function(menu="Segmentation > Threshold (Otsu et al 1979, scikit-image)")
 def threshold_otsu(image:ImageData) -> LabelsData:
     """
     Applies Otsu's threshold selection method to an intensity image and returns a binary image with pixels==1 where
@@ -91,23 +93,27 @@ def threshold_otsu(image:ImageData) -> LabelsData:
 
     return binary_otsu * 1
 
+@register_function(menu="Filtering > Gaussian blur (scikit-image)")
 def gaussian_blur(image:ImageData, sigma:float=1) -> ImageData:
     """
     Applies a Gaussian blur to an image with a defined sigma. Useful for denoising.
     """
     return gaussian(image, sigma)
 
+@register_function(menu="Filtering > Subtract background (rolling ball, scikit-image)")
 def subtract_background(image:ImageData, rolling_ball_radius:float = 5) -> ImageData:
     background = rolling_ball(image, radius = rolling_ball_radius)
     return image - background
 
 
+@register_function(menu="Segmentation > Invert binary image")
 def binary_invert(binary_image:LabelsData) -> LabelsData:
     """
     Inverts a binary image.
     """
     return (np.asarray(binary_image) == 0) * 1
 
+@register_function(menu="Segmentation > Connected component labeling")
 def connected_component_labeling(binary_image:LabelsData) -> LabelsData:
     """
     Takes a binary image and produces a label image with all separated objects labeled differently.
@@ -115,6 +121,7 @@ def connected_component_labeling(binary_image:LabelsData) -> LabelsData:
     return label(np.asarray(binary_image))
 
 
+@register_function(menu="Segmentation > Labeling (Voronoi-Otsu-labeling)")
 def voronoi_otsu_labeling(image:ImageData, spot_sigma: float = 2, outline_sigma: float = 2) -> LabelsData:
     """
     The two sigma parameters allow tuning the segmentation result. The first sigma controls how close detected cells
@@ -147,6 +154,7 @@ def voronoi_otsu_labeling(image:ImageData, spot_sigma: float = 2, outline_sigma:
 
     return labels
 
+@register_function(menu="Segmentation > Seeded watershed")
 def seeded_watershed(membranes:ImageData, labeled_nuclei:LabelsData) -> LabelsData:
     """
     Takes a image with brigh (high intensity) membranes and an image with labeled objects such as nuclei.
